* Code for analysis in "The Dynamic Free Rider Problem: A Laboratory Study" by Marco Battaglini, Salvatore Nunnari, and Thomas R. Palfrey
* Last edited: February 11, 2016

clear
set more off
use "bnp_dyngvc_data.dta"

* CODEBOOK
* treatment: treatment: "DR3" for RIE with n=3; "DR5" for RIE with n=5; 
*            "DIR3" for IIE with n=3; "DIR5" for IIE with n=5; 
*            "SR3" for reduced form RIE with n=3; "SR5" for reduced form RIE with n=5
* rev: dummy variale for reversible investment treatment
* n: members per group (3 or 5)
* expid: experimental session id: "1", "2" or "3"
* matchid: match id (session specific)
* roundid: round number
* groupid: group id
* subjectid: subject id (session specific; fixed for all session)
* index: group member id (0 to 2 for n=3; 0 to 4 for n=5; reassigned in every match)
* g: stock of the public good at the beginning of the round (in experimental units)
* y: stock of the public good at the end of the round (in experimental units)
* x: individual allocation to private consumption
* inv: individual allocation to public good investment
* totinv: group total allocation to public good investment 

egen uniqueexpid=concat(treatment expid), punct(_)
egen uniquesubjectid=concat(uniqueexpid subjectid), punct(_)

sort treatment expid matchid groupid roundid subjectid
gen groupmember1=.
replace groupmember1=subjectid if index==0
replace groupmember1=subjectid[_n-1] if index==1
replace groupmember1=subjectid[_n-2] if index==2
replace groupmember1=subjectid[_n-3] if index==3
replace groupmember1=subjectid[_n-4] if index==4
gen groupmember2=.
replace groupmember2=subjectid[_n+1] if index==0
replace groupmember2=subjectid if index==1
replace groupmember2=subjectid[_n-1] if index==2
replace groupmember2=subjectid[_n-2] if index==3
replace groupmember2=subjectid[_n-3] if index==4
gen groupmember3=.
replace groupmember3=subjectid[_n+2] if index==0
replace groupmember3=subjectid[_n+1] if index==1
replace groupmember3=subjectid if index==2
replace groupmember3=subjectid[_n-1] if index==3
replace groupmember3=subjectid[_n-2] if index==4
gen groupmember4=.
replace groupmember4=subjectid[_n+3] if index==0 & n==5
replace groupmember4=subjectid[_n+2] if index==1 & n==5 
replace groupmember4=subjectid[_n+1] if index==2 & n==5
replace groupmember4=subjectid if index==3 & n==5
replace groupmember4=subjectid[_n-1] if index==4 & n==5
gen groupmember5=.
replace groupmember5=subjectid[_n+4] if index==0 & n==5
replace groupmember5=subjectid[_n+3] if index==1 & n==5
replace groupmember5=subjectid[_n+2] if index==2 & n==5
replace groupmember5=subjectid[_n+1] if index==3 & n==5
replace groupmember5=subjectid if index==4 & n==5

rowsort groupmember1-groupmember5, gen(subjectid1-subjectid5)
egen uniquegroupid=concat(treatment expid subjectid1 subjectid2 subjectid3 subjectid4 subjectid5), punct(_)

gen n5=0
replace n5=1 if n==5

gen late=0
replace late=1 if matchid>5

* NOTE: THE DATA FOR FIGURE 1 & THE 4TH COLUMN OF TABLE 2 IS IN TABLES B1 & B2 IN APPENDIX B
* NOTE: THE DATA FOR FIGURE 3 IS IN TABLES B2 & B4 IN APPENDIX B

* P-VALUES FOR TESTS IN TABLE 3 CLUSTERING STANDARD ERRORS BY GROUPS COMPOSED OF SAME INDIVIDUALS
bys roundid: somersd rev y if index==0 & n==3 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: somersd rev y if index==0 & n==5 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: somersd n y if index==0 & rev==1 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: somersd n y if index==0 & rev==0 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)

* P-VALUES FOR TESTS IN TABLE 3 WITHOUT CLUSTERING STANDARD ERRORS
* THESE ARE USED WHEN NO STANDARD ERROR AVAILABLE FOR CONFIDENCE INTERVALS OBTAINED WITH TEST ABOVE
roundid: ranksum y if index==0 & n==3 & roundid==8 & treatment!="SR3" & treatment!="SR5", by(rev)
roundid: ranksum y if index==0 & n==3 & roundid==9 & treatment!="SR3" & treatment!="SR5", by(rev)
roundid: ranksum y if index==0 & n==3 & roundid==10 & treatment!="SR3" & treatment!="SR5", by(rev)
roundid: ranksum y if index==0 & n==5 & roundid==9 & treatment!="SR3" & treatment!="SR5", by(rev)
roundid: ranksum y if index==0 & n==5 & roundid==10 & treatment!="SR3" & treatment!="SR5", by(rev)

* TABLE B1
bys roundid: su y if treatment=="DR3" & index==0, detail
bys roundid: su y if treatment=="DR5" & index==0, detail

* TABLE B2
bys roundid: su y if treatment=="DIR3" & index==0, detail
bys roundid: su y if treatment=="DIR5" & index==0, detail

* TABLE B3
bys roundid: su inv if treatment=="DR3", detail
bys roundid: su inv if treatment=="DR5", detail

* TABLE B4
bys roundid: su inv if treatment=="DIR3", detail
bys roundid: su inv if treatment=="DIR5", detail

* P-VALUES FOR TESTS IN TABLE B5 CLUSTERING STANDARD ERRORS BY GROUPS COMPOSED OF SAME INDIVIDUALS
bys roundid: reg y rev if index==0 & n==3 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: reg y rev if index==0 & n==5 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: reg y n5 if index==0 & rev==1 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)
bys roundid: reg y n5 if index==0 & rev==0 & roundid<11 & treatment!="SR3" & treatment!="SR5", cluster(uniquegroupid)

* P-VALUES FOR TESTS IN TABLE B6 CLUSTERING STANDARD ERRORS BY GROUPS COMPOSED OF SAME INDIVIDUALS
bys roundid: somersd late y if index==0 & treatment=="DR3" & roundid<11, cluster(uniquegroupid)
bys roundid: somersd late y if index==0 & treatment=="DR5" & roundid<11, cluster(uniquegroupid)
bys roundid: somersd late y if index==0 & treatment=="DIR3" & roundid<11, cluster(uniquegroupid)
bys roundid: somersd late y if index==0 & treatment=="DIR5" & roundid<11, cluster(uniquegroupid)

* FIGURE 2 ("NORMEFF" = NORMALIZED EFFICIENCY)
gen y_mpe=.
replace y_mpe=21.33 if treatment=="DIR3" & roundid==1
replace y_mpe=27.05 if treatment=="DIR3" & roundid==2
replace y_mpe=30.97 if treatment=="DIR3" & roundid==3
replace y_mpe=33.93 if treatment=="DIR3" & roundid==4
replace y_mpe=36.30 if treatment=="DIR3" & roundid==5
replace y_mpe=38.25 if treatment=="DIR3" & roundid==6
replace y_mpe=39.90 if treatment=="DIR3" & roundid==7
replace y_mpe=41.31 if treatment=="DIR3" & roundid==8
replace y_mpe=42.55 if treatment=="DIR3" & roundid==9
replace y_mpe=43.64 if treatment=="DIR3" & roundid==10
replace y_mpe=44.61 if treatment=="DIR3" & roundid==11
replace y_mpe=18.87 if treatment=="DIR5" & roundid==1
replace y_mpe=24.55 if treatment=="DIR5" & roundid==2
replace y_mpe=28.54 if treatment=="DIR5" & roundid==3
replace y_mpe=31.63 if treatment=="DIR5" & roundid==4
replace y_mpe=34.14 if treatment=="DIR5" & roundid==5
replace y_mpe=36.24 if treatment=="DIR5" & roundid==6
replace y_mpe=38.05 if treatment=="DIR5" & roundid==7
replace y_mpe=39.63 if treatment=="DIR5" & roundid==8
replace y_mpe=41.03 if treatment=="DIR5" & roundid==9
replace y_mpe=42.28 if treatment=="DIR5" & roundid==10
replace y_mpe=43.41 if treatment=="DIR5" & roundid==11
replace y_mpe=7.11 if treatment=="DR3" 
replace y_mpe=5.54 if treatment=="DR5" 

gen y_eff=.
replace y_eff=60*roundid if n==3 & roundid<10
replace y_eff=576 if n==3 & roundid>9
replace y_eff=80*roundid if n==5 & roundid<12

gen normeff=.
replace normeff=(y-y_mpe)/(y_eff-y_mpe) if roundid<12

bys roundid: su normeff if treatment=="DIR3" & index==0 & roundid<11, detail
bys roundid: su normeff if treatment=="DIR5" & index==0 & roundid<11, detail
bys roundid: su normeff if treatment=="DR3" & index==0 & roundid<11, detail
bys roundid: su normeff if treatment=="DR5" & index==0 & roundid<11, detail

* FIGURE 4 ("DIFFINV" = DIFFERENCE WITH MPE INVESTMENT)
gen inv_mpe=.
replace inv_mpe=(7.11-g)/3 if treatment=="DR3" & g<=7.11
replace inv_mpe=-(g-7.11)/3 if treatment=="DR3" & g>7.11
replace inv_mpe=(5.54-g)/5 if treatment=="DR5" & g<=5.54
replace inv_mpe=-(g-5.54)/5 if treatment=="DR5" & g>5.54
replace inv_mpe=0 if g>=64 & treatment=="DIR5" | treatment=="DIR3"
replace inv_mpe=((8+1.5*g-4*sqrt(g))-g)/3 if g<64 & treatment=="DIR3"
replace inv_mpe=(6.67+1.42*g-3.33*sqrt(g)-g)/5 if g<64 & treatment=="DIR5"
gen diffinv=inv-inv_mpe

bys roundid: su diffinv if treatment=="DIR3" & roundid<11, detail
bys roundid: su diffinv if treatment=="DIR5" & roundid<11, detail
bys roundid: su diffinv if treatment=="DR3" & roundid<11, detail
bys roundid: su diffinv if treatment=="DR5" & roundid<11, detail

* FIGURE 5
bys roundid: su y if treatment=="DR3" & index==0 & late==0 & roundid<11, detail
bys roundid: su y if treatment=="DR5" & index==0 & late==0 & roundid<11, detail
bys roundid: su y if treatment=="DIR3" & index==0 & late==0 & roundid<11, detail
bys roundid: su y if treatment=="DIR5" & index==0 & late==0 & roundid<11, detail
bys roundid: su y if treatment=="DR3" & index==0 & late==1 & roundid<11, detail
bys roundid: su y if treatment=="DR5" & index==0 & late==1 & roundid<11, detail
bys roundid: su y if treatment=="DIR3" & index==0 & late==1 & roundid<11, detail
bys roundid: su y if treatment=="DIR5" & index==0 & late==1 & roundid<11, detail

* TABLE 4
egen uniquegroupid2=concat(treatment expid matchid groupid), punct(_)

bys uniquegroupid2 roundid: egen avginv=mean(inv)
bys uniquegroupid2 roundid: egen sdinv=sd(inv)
bys uniquegroupid2 roundid: egen mininv=min(inv)
bys uniquegroupid2 roundid: egen maxinv=max(inv)

sort uniquegroupid2 roundid index
gen inv0=.
gen inv1=.
gen inv2=.
gen inv3=.
gen inv4=.
replace inv0=inv if index==0
replace inv0=inv[_n-1] if index==1
replace inv0=inv[_n-2] if index==2
replace inv0=inv[_n-3] if index==3
replace inv0=inv[_n-4] if index==4
replace inv1=inv if index==1
replace inv1=inv[_n+1] if index==0
replace inv1=inv[_n-1] if index==2
replace inv1=inv[_n-2] if index==3
replace inv1=inv[_n-3] if index==4
replace inv2=inv if index==2
replace inv2=inv[_n+2] if index==0
replace inv2=inv[_n+1] if index==1
replace inv2=inv[_n-1] if index==3
replace inv2=inv[_n-2] if index==4
replace inv3=inv if index==3
replace inv3=inv[_n+3] if index==0  & n==5
replace inv3=inv[_n+2] if index==1  & n==5
replace inv3=inv[_n+1] if index==2  & n==5  
replace inv3=inv[_n-1] if index==4  
replace inv4=inv if index==4
replace inv4=inv[_n+4] if index==0  & n==5
replace inv4=inv[_n+3] if index==1  & n==5
replace inv4=inv[_n+2] if index==2
replace inv4=inv[_n+1] if index==3

egen avginv_others0=rowmean(inv1 inv2 inv3 inv4)
egen avginv_others1=rowmean(inv0 inv2 inv3 inv4)
egen avginv_others2=rowmean(inv1 inv0 inv3 inv4)
egen avginv_others3=rowmean(inv1 inv2 inv0 inv4)
egen avginv_others4=rowmean(inv1 inv2 inv3 inv0)

egen sdinv_others0=rowsd(inv1 inv2 inv3 inv4)
egen sdinv_others1=rowsd(inv0 inv2 inv3 inv4)
egen sdinv_others2=rowsd(inv1 inv0 inv3 inv4)
egen sdinv_others3=rowsd(inv1 inv2 inv0 inv4)
egen sdinv_others4=rowsd(inv1 inv2 inv3 inv0)

gen avginv_others=.
replace avginv_others=avginv_others0 if index==0
replace avginv_others=avginv_others1 if index==1
replace avginv_others=avginv_others2 if index==2
replace avginv_others=avginv_others3 if index==3
replace avginv_others=avginv_others4 if index==4

gen sdinv_others=.
replace sdinv_others=sdinv_others0 if index==0
replace sdinv_others=sdinv_others1 if index==1
replace sdinv_others=sdinv_others2 if index==2
replace sdinv_others=sdinv_others3 if index==3
replace sdinv_others=sdinv_others4 if index==4

drop avginv_others0 avginv_others1 avginv_others2 avginv_others3 avginv_others4 sdinv_others0 sdinv_others1 sdinv_others2 sdinv_others3 sdinv_others4

gen lag_avginv=.
gen lag_sdinv=.
gen lag_avginv_others=.
gen lag_sdinv_others=.
replace lag_avginv=avginv[_n-3] if n==3
replace lag_avginv=avginv[_n-5] if n==5
replace lag_sdinv=sdinv[_n-3] if n==3
replace lag_sdinv=sdinv[_n-5] if n==5
replace lag_avginv_others=avginv_others[_n-3] if n==3
replace lag_avginv_others=avginv_others[_n-5] if n==5
replace lag_sdinv_others=sdinv_others[_n-3] if n==3
replace lag_sdinv_others=sdinv_others[_n-5] if n==5

replace lag_avginv=. if roundid==1
replace lag_sdinv=. if roundid==1
replace lag_avginv_others=. if roundid==1
replace lag_sdinv_others=. if roundid==1

xi: tobit inv g lag_avginv lag_sdinv  i.uniquesubjectid if treatment=="DR3", ul cluster(uniquegroupid)
xi: tobit inv g lag_avginv lag_sdinv  i.uniquesubjectid if treatment=="DR5", ul cluster(uniquegroupid)
xi: tobit inv g lag_avginv lag_sdinv  i.uniquesubjectid if treatment=="DIR3", ll ul cluster(uniquegroupid)
xi: tobit inv g lag_avginv lag_sdinv  i.uniquesubjectid if treatment=="DIR5", ll ul cluster(uniquegroupid)

************************
* FIGURE 6 AND TABLE 6 *
************************

clear
set more off
use "bnp_dyngvc_data.dta"
egen uniqueexpid=concat(treatment expid), punct(_)
egen uniquesubjectid=concat(uniqueexpid subjectid), punct(_)

gen gbin=.
replace gbin=0 if g==0
replace gbin=5 if g>=2 & g<=8
replace gbin=10 if g>=7 & g<=13
replace gbin=15 if g>=12 & g<=18
replace gbin=20 if g>=17 & g<=23
replace gbin=25 if g>=22 & g<=28
replace gbin=30 if g>=27 & g<=33
replace gbin=35 if g>=32 & g<=38
replace gbin=g if (treatment=="SR3" | treatment=="SR5")

bys gbin: su inv if treatment=="SR3", detail
bys gbin: su inv if treatment=="SR5", detail
bys gbin: su inv if treatment=="DR3", detail
bys gbin: su inv if treatment=="DR5", detail

gen static=.
replace static=1 if (treatment=="SR3" | treatment=="SR5")
replace static=0 if (treatment=="DR3" | treatment=="DR5")

* P-VALUES FOR TESTS IN TABLE 6
bys gbin: somersd static inv if n==3 & rev==1 & gbin!=., cluster(uniquesubjectid)
bys gbin: somersd static inv if n==5 & rev==1 & gbin!=., cluster(uniquesubjectid)

**************************************************************
* TABLE 7: SUBJECTS CLASSIFICATION A' LA FISCHERBACHER ET AL *
**************************************************************

clear
set mem 50000
set more off
use "bnp_dyngvc_data.dta"

drop if treatment=="SR3" | treatment=="SR5"

egen uniqueid=concat(treatment expid subjectid), punct(_)
egen uniquegroupid=concat(treatment expid matchid groupid), punct(_)


gen predinvr=.
replace predinvr=(1.77-gr)/3 if treatment=="DR3"
replace predinvr=(1.38-gr)/5 if treatment=="DR5"
replace predinvr=0 if gr>=16 & treatment=="DIR3"
replace predinvr=0 if gr>=16 & treatment=="DIR5"
replace predinvr=((8+1.5*gr-4*sqrt(gr))-gr)/3 if gr<16 & treatment=="DIR3"
replace predinvr=(6.67+1.42*gr-3.33*sqrt(gr)-gr)/5 if gr<16 & treatment=="DIR5"
gen predinv=predinvr*4
gen devinv=inv-predinv
drop predinvr predinv

bysort uniqueid: egen avg_inv=mean(inv)
bysort uniqueid: egen avg_devinv=mean(devinv)
bysort uniquegroupid roundid: egen avg_inv_group=mean(inv)

gen treatment_num=1
replace treatment_num=2 if treatment=="DR5"
replace treatment_num=3 if treatment=="DIR3"
replace treatment_num=4 if treatment=="DIR5"

egen id=concat(treatment_num expid matchid groupid), punct(_)
sort id roundid index
by id: gen id2=_n
egen id3=concat(treatment_num expid matchid groupid)
destring id3, replace
sort id3 id2
tsset id3 id2

gen avginv_group_lag=.
replace avginv_group_lag=lllll.avg_inv_group if n==5
replace avginv_group_lag=lll.avg_inv_group if n==3

gen avgdevinv_lag=.
replace avgdevinv_lag=lllll.avgdevinv if n==5
replace avgdevinv_lag=lll.avgdevinv if n==3

gen varinv_lag=.
replace varinv_lag=lllll.varinv if n==5
replace varinv_lag=lll.varinv if n==3

gen totinv_lag=.
replace totinv_lag=lllll.totinv if n==5
replace totinv_lag=lll.totinv if n==3

gen avginv_others=.
replace avginv_others=(f.inv+ff.inv)/2 if index==0 & n==3
replace avginv_others=(l.inv+f.inv)/2 if index==1 & n==3
replace avginv_others=(l.inv+ll.inv)/2 if index==2 & n==3

replace avginv_others=(f.inv+ff.inv+fff.inv+ffff.inv)/4 if index==0 & n==5
replace avginv_others=(l.inv+f.inv+ff.inv+fff.inv)/4 if index==1 & n==5
replace avginv_others=(ll.inv+l.inv+f.inv+ff.inv)/4 if index==2 & n==5
replace avginv_others=(lll.inv+ll.inv+l.inv+f.inv)/4 if index==3 & n==5
replace avginv_others=(llll.inv+lll.inv+ll.inv+l.inv)/4 if index==4 & n==5

gen avginv_others_lag=.
replace avginv_others_lag=lllll.avginv_others if n==5
replace avginv_others_lag=lll.avginv_others if n==3

gen avginv_others_lagr=avginv_others_lag/4

gen avgdevinv_others=.
replace avgdevinv_others=(f.devinv+ff.devinv)/2 if index==0 & n==3
replace avgdevinv_others=(l.devinv+f.devinv)/2 if index==1 & n==3
replace avgdevinv_others=(l.devinv+ll.devinv)/2 if index==2 & n==3
replace avgdevinv_others=(f.devinv+ff.devinv+fff.devinv+ffff.devinv)/4 if index==0 & n==5
replace avgdevinv_others=(l.devinv+f.devinv+ff.devinv+fff.devinv)/4 if index==1 & n==5
replace avgdevinv_others=(ll.devinv+l.devinv+f.devinv+ff.devinv)/4 if index==2 & n==5
replace avgdevinv_others=(lll.devinv+ll.devinv+l.devinv+f.devinv)/4 if index==3 & n==5
replace avgdevinv_others=(llll.devinv+lll.devinv+ll.devinv+l.devinv)/4 if index==4 & n==5

gen avgdevinv_others_lag=.
replace avgdevinv_others_lag=lllll.avginv_others if n==5
replace avgdevinv_others_lag=lll.avginv_others if n==3

gen avgdevinv_others_lagr=avgdevinv_others_lag/4
replace avginv_others_lag=avginv_group_lag

forval i=0/11 { 
	tobit inv avginv_others_lag if treatment=="DR3" & expid==1 & subjectid==`i', ul robust 
	gen DR3_1_coeff_`i'=_b[avginv_others_lag]
    gen DR3_1_se_`i'=_se[avginv_others_lag]
    gen DR3_1_coeffc_`i'=_b[_cons]
    gen DR3_1_sec_`i'=_se[_cons]
    }

forval i=0/8 { 
	tobit inv avginv_others_lag if treatment=="DR3" & expid==2 & subjectid==`i', ul robust 
	gen DR3_2_coeff_`i'=_b[avginv_others_lag]
    gen DR3_2_se_`i'=_se[avginv_others_lag]
    gen DR3_2_coeffc_`i'=_b[_cons]
    gen DR3_2_sec_`i'=_se[_cons]
    }

forval i=0/11 { 
	tobit inv avginv_others_lag if treatment=="DR3" & expid==3 & subjectid==`i', ul robust 
	gen DR3_3_coeff_`i'=_b[avginv_others_lag]
    gen DR3_3_se_`i'=_se[avginv_others_lag]
    gen DR3_3_coeffc_`i'=_b[_cons]
    gen DR3_3_sec_`i'=_se[_cons]
    }

forval i=0/14 { 
	tobit inv avginv_others_lag if treatment=="DR5" & expid==1 & subjectid==`i', ul robust 
	gen DR5_3_coeff_`i'=_b[avginv_others_lag]
    gen DR5_3_se_`i'=_se[avginv_others_lag]
    gen DR5_3_coeffc_`i'=_b[_cons]
    gen DR5_3_sec_`i'=_se[_cons]
    }

forval i=0/14 { 
	tobit inv avginv_others_lag if treatment=="DR5" & expid==2 & subjectid==`i', ul robust 
	gen DR5_8_coeff_`i'=_b[avginv_others_lag]
    gen DR5_8_se_`i'=_se[avginv_others_lag]
    gen DR5_8_coeffc_`i'=_b[_cons]
    gen DR5_8_sec_`i'=_se[_cons]
    }
    
forval i=0/11 { 
	tobit inv avginv_others_lag if treatment=="DIR3" & expid==1 & subjectid==`i', ul robust 
	gen DIR3_1_coeff_`i'=_b[avginv_others_lag]
    gen DIR3_1_se_`i'=_se[avginv_others_lag]
    gen DIR3_1_coeffc_`i'=_b[_cons]
    gen DIR3_1_sec_`i'=_se[_cons]
    }

forval i=0/11 { 
	tobit inv avginv_others_lag if treatment=="DIR3" & expid==2 & subjectid==`i', ul robust 
	gen DIR3_2_coeff_`i'=_b[avginv_others_lag]
    gen DIR3_2_se_`i'=_se[avginv_others_lag]
    gen DIR3_2_coeffc_`i'=_b[_cons]
    gen DIR3_2_sec_`i'=_se[_cons]
    }

forval i=0/5 { 
	tobit inv avginv_others_lag if treatment=="DIR3" & expid==3 & subjectid==`i', ul robust 
	gen DIR3_3_coeff_`i'=_b[avginv_others_lag]
    gen DIR3_3_se_`i'=_se[avginv_others_lag]
    gen DIR3_3_coeffc_`i'=_b[_cons]
    gen DIR3_3_sec_`i'=_se[_cons]
    }
    
gen DIR3_3_coeff_6=0 
gen DIR3_3_se_6=0 
gen DIR3_3_coeffc_6=0 
gen DIR3_3_sec_6=0

forval i=7/11 { 
	tobit inv avginv_others_lag if treatment=="DIR3" & expid==3 & subjectid==`i', ul robust 
	gen DIR3_3_coeff_`i'=_b[avginv_others_lag]
    gen DIR3_3_se_`i'=_se[avginv_others_lag]
    gen DIR3_3_coeffc_`i'=_b[_cons]
    gen DIR3_3_sec_`i'=_se[_cons]
    }
    
forval i=0/4 { 
	tobit inv avginv_others_lag if treatment=="DIR5" & expid==1 & subjectid==`i', ul robust 
	gen DIR5_1_coeff_`i'=_b[avginv_others_lag]
    gen DIR5_1_se_`i'=_se[avginv_others_lag]
    gen DIR5_1_coeffc_`i'=_b[_cons]
    gen DIR5_1_sec_`i'=_se[_cons]
    }
    
 forval i=6/14 { 
	tobit inv avginv_others_lag if treatment=="DIR5" & expid==1 & subjectid==`i', ul robust 
	gen DIR5_1_coeff_`i'=_b[avginv_others_lag]
    gen DIR5_1_se_`i'=_se[avginv_others_lag]
    gen DIR5_1_coeffc_`i'=_b[_cons]
    gen DIR5_1_sec_`i'=_se[_cons]
    }
    
    gen DIR5_1_coeff_5=0 if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_se_5=0 if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_coeffc_5=0 if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_sec_5=0 if treatment=="DIR5" & expid==1 & subjectid==5

forval i=0/14 { 
	tobit inv avginv_others_lag if treatment=="DIR5" & expid==2 & subjectid==`i', ul robust 
	gen DIR5_2_coeff_`i'=_b[avginv_others_lag]
    gen DIR5_2_se_`i'=_se[avginv_others_lag]
    gen DIR5_2_coeffc_`i'=_b[_cons]
    gen DIR5_2_sec_`i'=_se[_cons]
    }
    
gen coeff_avginvotherslag=.
gen se_avginvotherslag=.
gen coeff_constant=.
gen se_constant=.
    
    forval i=0/11 { 
    replace coeff_avginvotherslag=DR3_1_coeff_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace se_avginvotherslag=DR3_1_se_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace coeff_constant=DR3_1_coeffc_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace se_constant=DR3_1_sec_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    }
    forval i=0/8 { 
    replace coeff_avginvotherslag=DR3_2_coeff_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace se_avginvotherslag=DR3_2_se_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace coeff_constant=DR3_2_coeffc_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace se_constant=DR3_2_sec_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff_avginvotherslag=DR3_3_coeff_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace se_avginvotherslag=DR3_3_se_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace coeff_constant=DR3_3_coeffc_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace se_constant=DR3_3_sec_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff_avginvotherslag=DR5_3_coeff_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace se_avginvotherslag=DR5_3_se_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace coeff_constant=DR5_3_coeffc_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace se_constant=DR5_3_sec_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff_avginvotherslag=DR5_8_coeff_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace se_avginvotherslag=DR5_8_se_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace coeff_constant=DR5_8_coeffc_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace se_constant=DR5_8_sec_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff_avginvotherslag=DIR3_1_coeff_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace se_avginvotherslag=DIR3_1_se_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace coeff_constant=DIR3_1_coeffc_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace se_constant=DIR3_1_sec_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff_avginvotherslag=DIR3_2_coeff_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace se_avginvotherslag=DIR3_2_se_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace coeff_constant=DIR3_2_coeffc_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace se_constant=DIR3_2_sec_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff_avginvotherslag=DIR3_3_coeff_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace se_avginvotherslag=DIR3_3_se_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace coeff_constant=DIR3_3_coeffc_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace se_constant=DIR3_3_sec_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff_avginvotherslag=DIR5_1_coeff_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace se_avginvotherslag=DIR5_1_se_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace coeff_constant=DIR5_1_coeffc_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace se_constant=DIR5_1_sec_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff_avginvotherslag=DIR5_2_coeff_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace se_avginvotherslag=DIR5_2_se_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace coeff_constant=DIR5_2_coeffc_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace se_constant=DIR5_2_sec_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    }
    
drop DR3_1_coeff_0- DIR5_2_se_14
    
forval i=0/11 { 
	tobit devinv avginv_others_lag if treatment=="DR3" & expid==1 & subjectid==`i', ul robust 
	gen DR3_1_coeff2_`i'=_b[avginv_others_lag]
    gen DR3_1_se2_`i'=_se[avginv_others_lag]
    gen DR3_1_coeff2c_`i'=_b[_cons]
    gen DR3_1_se2c_`i'=_se[_cons]
    }

forval i=0/8 { 
	tobit devinv avginv_others_lag if treatment=="DR3" & expid==2 & subjectid==`i', ul robust 
	gen DR3_2_coeff2_`i'=_b[avginv_others_lag]
    gen DR3_2_se2_`i'=_se[avginv_others_lag]
    gen DR3_2_coeff2c_`i'=_b[_cons]
    gen DR3_2_se2c_`i'=_se[_cons]
    }

forval i=0/11 { 
	tobit devinv avginv_others_lag if treatment=="DR3" & expid==3 & subjectid==`i', ul robust 
	gen DR3_3_coeff2_`i'=_b[avginv_others_lag]
    gen DR3_3_se2_`i'=_se[avginv_others_lag]
    gen DR3_3_coeff2c_`i'=_b[_cons]
    gen DR3_3_se2c_`i'=_se[_cons]
    }
    
forval i=0/14 { 
	tobit devinv avginv_others_lag if treatment=="DR5" & expid==1 & subjectid==`i', ul robust 
	gen DR5_3_coeff2_`i'=_b[avginv_others_lag]
    gen DR5_3_se2_`i'=_se[avginv_others_lag]
    gen DR5_3_coeff2c_`i'=_b[_cons]
    gen DR5_3_se2c_`i'=_se[_cons]
    }

forval i=0/14 { 
	tobit devinv avginv_others_lag if treatment=="DR5" & expid==2 & subjectid==`i', ul robust 
	gen DR5_8_coeff2_`i'=_b[avginv_others_lag]
    gen DR5_8_se2_`i'=_se[avginv_others_lag]
    gen DR5_8_coeff2c_`i'=_b[_cons]
    gen DR5_8_se2c_`i'=_se[_cons]
    }
    
forval i=0/11 { 
	tobit devinv avginv_others_lag if treatment=="DIR3" & expid==1 & subjectid==`i', ul robust 
	gen DIR3_1_coeff2_`i'=_b[avginv_others_lag]
    gen DIR3_1_se2_`i'=_se[avginv_others_lag]
    gen DIR3_1_coeff2c_`i'=_b[_cons]
    gen DIR3_1_se2c_`i'=_se[_cons]
    }

forval i=0/11 { 
	tobit devinv avginv_others_lag if treatment=="DIR3" & expid==2 & subjectid==`i', ul robust 
	gen DIR3_2_coeff2_`i'=_b[avginv_others_lag]
    gen DIR3_2_se2_`i'=_se[avginv_others_lag]
    gen DIR3_2_coeff2c_`i'=_b[_cons]
    gen DIR3_2_se2c_`i'=_se[_cons]
    }

forval i=0/5 { 
	tobit devinv avginv_others_lag if treatment=="DIR3" & expid==3 & subjectid==`i', ul robust 
	gen DIR3_3_coeff2_`i'=_b[avginv_others_lag]
    gen DIR3_3_se2_`i'=_se[avginv_others_lag]
    gen DIR3_3_coeff2c_`i'=_b[_cons]
    gen DIR3_3_se2c_`i'=_se[_cons]
    }
        
gen DIR3_3_coeff2_6=0 
gen DIR3_3_se2_6=0 
gen DIR3_3_coeff2c_6=0 
gen DIR3_3_se2c_6=0

forval i=7/11 { 
	tobit devinv avginv_others_lag if treatment=="DIR3" & expid==3 & subjectid==`i', ul robust 
	gen DIR3_3_coeff2_`i'=_b[avginv_others_lag]
    gen DIR3_3_se2_`i'=_se[avginv_others_lag]
    gen DIR3_3_coeff2c_`i'=_b[_cons]
    gen DIR3_3_se2c_`i'=_se[_cons]
    }
    
forval i=0/4 { 
	tobit devinv avginv_others_lag if treatment=="DIR5" & expid==1 & subjectid==`i', ul robust 
	gen DIR5_1_coeff2_`i'=_b[avginv_others_lag]
    gen DIR5_1_se2_`i'=_se[avginv_others_lag]
    gen DIR5_1_coeff2c_`i'=_b[_cons]
    gen DIR5_1_se2c_`i'=_se[_cons]
    }
    
 forval i=6/14 { 
	tobit devinv avginv_others_lag if treatment=="DIR5" & expid==1 & subjectid==`i', ul robust 
	gen DIR5_1_coeff2_`i'=_b[avginv_others_lag]
    gen DIR5_1_se2_`i'=_se[avginv_others_lag]
    gen DIR5_1_coeff2c_`i'=_b[_cons]
    gen DIR5_1_se2c_`i'=_se[_cons]
    }
    
    gen DIR5_1_coeff2_5=. if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_se2_5=. if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_coeff2c_5=. if treatment=="DIR5" & expid==1 & subjectid==5
    gen DIR5_1_se2c_5=. if treatment=="DIR5" & expid==1 & subjectid==5

forval i=0/14 { 
	tobit devinv avginv_others_lag if treatment=="DIR5" & expid==2 & subjectid==`i', ul robust 
	gen DIR5_2_coeff2_`i'=_b[avginv_others_lag]
    gen DIR5_2_se2_`i'=_se[avginv_others_lag]
    gen DIR5_2_coeff2c_`i'=_b[_cons]
    gen DIR5_2_se2c_`i'=_se[_cons]
    }
    
gen coeff2_avginvotherslag=.
gen se2_avginvotherslag=.
gen coeff2_constant=.
gen se2_constant=.
    
    forval i=0/11 { 
    replace coeff2_avginvotherslag=DR3_1_coeff2_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace se2_avginvotherslag=DR3_1_se2_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace coeff2_constant=DR3_1_coeff2c_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    replace se2_constant=DR3_1_se2c_`i' if treatment=="DR3" & expid==1 & subjectid==`i'
    }
    forval i=0/8 { 
    replace coeff2_avginvotherslag=DR3_2_coeff2_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace se2_avginvotherslag=DR3_2_se2_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace coeff2_constant=DR3_2_coeff2c_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    replace se2_constant=DR3_2_se2c_`i' if treatment=="DR3" & expid==2 & subjectid==`i'
    }
     forval i=0/11 { 
    replace coeff2_avginvotherslag=DR3_3_coeff2_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace se2_avginvotherslag=DR3_3_se2_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace coeff2_constant=DR3_3_coeff2c_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    replace se2_constant=DR3_3_se2c_`i' if treatment=="DR3" & expid==3 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff2_avginvotherslag=DR5_3_coeff2_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace se2_avginvotherslag=DR5_3_se2_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace coeff2_constant=DR5_3_coeff2c_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    replace se2_constant=DR5_3_se2c_`i' if treatment=="DR5" & expid==1 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff2_avginvotherslag=DR5_8_coeff2_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace se2_avginvotherslag=DR5_8_se2_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace coeff2_constant=DR5_8_coeff2c_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    replace se2_constant=DR5_8_se2c_`i' if treatment=="DR5" & expid==2 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff2_avginvotherslag=DIR3_1_coeff2_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace se2_avginvotherslag=DIR3_1_se2_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace coeff2_constant=DIR3_1_coeff2c_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    replace se2_constant=DIR3_1_se2c_`i' if treatment=="DIR3" & expid==1 & subjectid==`i'
    }
    forval i=0/11 { 
    replace coeff2_avginvotherslag=DIR3_2_coeff2_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace se2_avginvotherslag=DIR3_2_se2_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace coeff2_constant=DIR3_2_coeff2c_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    replace se2_constant=DIR3_2_se2c_`i' if treatment=="DIR3" & expid==2 & subjectid==`i'
    }
     forval i=0/11 { 
    replace coeff2_avginvotherslag=DIR3_3_coeff2_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace se2_avginvotherslag=DIR3_3_se2_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace coeff2_constant=DIR3_3_coeff2c_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    replace se2_constant=DIR3_3_se2c_`i' if treatment=="DIR3" & expid==3 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff2_avginvotherslag=DIR5_1_coeff2_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace se2_avginvotherslag=DIR5_1_se2_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace coeff2_constant=DIR5_1_coeff2c_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    replace se2_constant=DIR5_1_se2c_`i' if treatment=="DIR5" & expid==1 & subjectid==`i'
    }
    forval i=0/14 { 
    replace coeff2_avginvotherslag=DIR5_2_coeff2_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace se2_avginvotherslag=DIR5_2_se2_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace coeff2_constant=DIR5_2_coeff2c_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    replace se2_constant=DIR5_2_se2c_`i' if treatment=="DIR5" & expid==2 & subjectid==`i'
    }

drop DR3_1_coeff2_0- DIR5_2_se2_14

bysort uniqueid: keep if _n==1

gen t_avginvotherslag=abs(coeff_avginvotherslag)/se_avginvotherslag
gen t_constant=abs(coeff_constant)/se_constant
gen t2_avginvotherslag=abs(coeff2_avginvotherslag)/se2_avginvotherslag
gen t2_constant=abs(coeff2_constant)/se2_constant

sort treatment
by treatment: egen avg_inv_cut1=pctile(avg_inv), p(33)
by treatment: egen avg_inv_cut2=pctile(avg_inv), p(66)
by treatment: egen avg_devinv_cut1=pctile(avg_devinv), p(33)
by treatment: egen avg_devinv_cut2=pctile(avg_devinv), p(66)

* CONDITIONAL COOPERATOR: SLOPE DIFFERENT THAN 0 (SIGNIFICANT AT 1% LEVEL, THAT IS T>=2.576)
* UNCONDITIONAL COOPERATOR: HIGH AVGDEVINV (IN THIRD QUANTILE) & SLOPE ~ 0
* FREE RIDER: LOW AVGDEVINV (IN FIRST QUANTILE) & SLOPE ~ 0

gen category="UNCLASSIFIED"
replace category="FREE RIDER" if t2_avginvotherslag<2.576 & avg_devinv<avg_devinv_cut1
replace category="CONDITIONAL COOPERATOR" if t2_avginvotherslag>=2.576
replace category="ALTRUIST" if t2_avginvotherslag<2.576 & avg_devinv>avg_devinv_cut2

* TABLE 7 - COLUMN OVERALL
tab category 

* TABLE 7 - OTHER COLUMNS
bysort treatment: tab category
